@@ -137,6 +137,7 @@ directory_load_cb (GnomeVFSAsyncHandle *handle,
 			break;
 
 		default:
+			break;
 		}
 
 		if (full_uri)
@@ -445,7 +446,9 @@ path_list_new (const char  *text_uri,
 		char *             str_uri;
 		char *             unesc_uri;
 
+#ifdef DEBUG
 		g_print ("--> %s\n", info->name);
+#endif
 
 		switch (info->type) {
 		case GNOME_VFS_FILE_TYPE_REGULAR:
@@ -453,6 +456,10 @@ path_list_new (const char  *text_uri,
 			str_uri = gnome_vfs_uri_to_string (full_uri, GNOME_VFS_URI_HIDE_NONE);
 			unesc_uri = gnome_vfs_unescape_string (str_uri, NULL);
 
+#ifdef DEBUG
+			g_print ("--> %s\n", unesc_uri);
+#endif
+
 			file_list = g_list_prepend (file_list, unesc_uri);
 			g_free (str_uri);
 			break;
@@ -1022,15 +1029,12 @@ is_desktop_file (const char *uri)
 
 	if (result != GNOME_VFS_OK) 
 		is_desktop = FALSE;
-	
-	if (info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_TYPE &&
-	    info->type == GNOME_VFS_FILE_TYPE_REGULAR &&
-	    info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_MIME_TYPE &&
-	    strcmp (info->mime_type, "application/x-gnome-app-info") != 0) 
+	else if ((strcmp (info->mime_type, "application/x-gnome-app-info") != 0)
+		 && (strcmp (info->mime_type, "application/x-desktop") != 0)) 
 		is_desktop = FALSE;
-		
+	
 	gnome_vfs_file_info_unref (info);
-
+	
 	return is_desktop;
 }
 
