@@ -3,7 +3,7 @@
 /*
  *  Quick Lounge Applet
  *
- *  Copyright (C) 2001 The Free Software Foundation, Inc.
+ *  Copyright (C) 2001, 2004 The Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -106,12 +106,14 @@ help_verb_cb (BonoboUIComponent *uic,
 {
 	GError *error = NULL;
 
-	gnome_help_display_desktop (NULL, 
-				    "quick-lounge-applet", 
-				    NULL,
-				    NULL, 
-				    &error);
-	
+	gnome_help_display_desktop_on_screen (
+	      NULL,
+	      "quick-lounge", 
+	      "quick-lounge", 
+	      NULL, 
+	      gtk_widget_get_screen (GTK_WIDGET (quick_lounge->applet)),
+	      &error);
+
 	if (error) {       
 		_gtk_error_dialog_run (NULL, 
 				       ERROR_FORMAT, 
@@ -134,6 +136,7 @@ about_verb_cb (BonoboUIComponent *uic,
 		NULL
 	};
 	const char *documenters [] = {
+		"Sun GNOME Documentation Team",
 		NULL
 	};
 	const char *translator_credits = _("translator_credits");
@@ -223,6 +226,9 @@ applet_destroy (GtkWidget    *applet,
 
 	if (quick_lounge->about_dialog != NULL)
                 gtk_widget_destroy (quick_lounge->about_dialog);
+	if (quick_lounge->prop_dialog != NULL)
+                gtk_widget_destroy (quick_lounge->prop_dialog);
+
 	g_free (quick_lounge->location);
 
 	if (quick_lounge->ditem_hash != NULL) {
@@ -494,9 +500,6 @@ ditem_properties_close (GtkWidget *dialog,
 }
 
 
-/* ---- 8< ---- 8< ---- */
-
-
 void
 quick_lounge_util__item_properties (QuickLounge *quick_lounge,
 				    GtkWidget   *button)
@@ -604,160 +607,6 @@ item_move_cb (GtkWidget *button)
 }
 
 
-/* -- show help on app -- */
-
-/* -----8<----- cut & paste from the gnome-panel -----8<----- */
-
-GQuark
-panel_help_error_quark (void)
-{
-        static GQuark q = 0;
-        if (q == 0)
-                q = g_quark_from_static_string ("panel-help-error-quark");
-
-        return q;
-}
-
-typedef enum {
-        PANEL_HELP_ERROR_NO_DOCPATH /* No docpath sent */,
-        PANEL_HELP_ERROR_NOT_FOUND /* Document not found */
-} PanelHelpError;
-
-#define PANEL_HELP_ERROR panel_help_error_quark ()
-
-static gboolean
-panel_show_gnome_help (const char *docpath, GError **error)
-{
-        char *app, *p, *path;
-        gboolean retval;
-
-        app = g_strdup (docpath);
-
-        p = strchr (app, '/');
-
-        if (p == NULL) {
-                g_free (app);
-                g_set_error (error,
-                             PANEL_HELP_ERROR,
-                             PANEL_HELP_ERROR_NOT_FOUND,
-                             /* XXX: Not really a correct error,
-                              * but just somewhat correct */
-                             _("Help document not found"));
-                return FALSE;
-        }
-
-        path = p+1;
-        *p = '\0';
-
-        retval = TRUE;
-
-        if ( ! gnome_help_display_desktop (NULL /* program */,
-                                           app /* doc_id */,
-                                           path /* file_name */,
-                                           NULL /* link_id */,
-                                           error)) {
-                retval = gnome_help_display_with_doc_id (NULL /* program */,
-                                                         app /* doc_id */,
-                                                         path /* file_name */,
-                                                         NULL /* link_id */,
-                                                         error);
-        }
-
-        g_free (app);
-
-        return retval;
-}
-
-
-static gboolean
-panel_show_kde_help (const char *docpath, GError **error)
-{
-        const GList *li;
-
-        if ( ! g_file_test (KDE_DOCDIR, G_FILE_TEST_EXISTS)) {
-                g_set_error (error,
-                             PANEL_HELP_ERROR,
-                             PANEL_HELP_ERROR_NOT_FOUND,
-                             _("Help document not found"));
-                return FALSE;
-        }
-
-        for (li = gnome_i18n_get_language_list ("LC_MESSAGES");
-             li != NULL;
-             li = li->next) {
-                char *fullpath = g_strdup_printf ("%s/HTML/%s/%s",
-                                                  KDE_DOCDIR,
-                                                  (char *)li->data,
-                                                  docpath);
-                if (g_file_test (fullpath, G_FILE_TEST_EXISTS)) {
-                        gboolean retval;
-                        char *uri = g_strconcat ("ghelp:", fullpath, NULL);
-                        g_free (fullpath);
-                        retval = gnome_help_display_uri (uri, error);
-                        g_free (uri);
-                        return retval;
-                }
-                g_free (fullpath);
-        }
-	
-	g_set_error (error,
-                     PANEL_HELP_ERROR,
-                     PANEL_HELP_ERROR_NOT_FOUND,
-                     _("Help document not found"));
-
-        return FALSE;
-}
-
-
-/* is url showable by gnome_url_show */
-gboolean
-panel_is_url (const char *url)
-{
-        if (strncmp (url, "http://", strlen ("http://")) == 0 ||
-            strncmp (url, "https://", strlen ("https://")) == 0 ||
-            strncmp (url, "gopher://", strlen ("gopher://")) == 0 ||
-            strncmp (url, "ftp://", strlen ("ftp://")) == 0 ||
-            strncmp (url, "file:", strlen ("file:")) == 0 ||
-            strncmp (url, "ghelp:", strlen ("ghelp:")) == 0 ||
-            strncmp (url, "help:", strlen ("help:")) == 0 ||
-            strncmp (url, "man:", strlen ("man:")) == 0 ||
-            strncmp (url, "info:", strlen ("info:")) == 0)
-                return TRUE;
-        else
-                return FALSE;
-}
-
-
-/* -----8<----- cut & paste from the gnome-panel -----8<----- */
-
-
-static void
-item_help_on_app_cb (GtkWidget *button)
-{
-	GnomeDesktopItem *ditem;
-	const char       *docpath;
-	GError           *err = NULL;
-
-	ditem = g_object_get_data (G_OBJECT (button), "ditem");
-	docpath = gnome_desktop_item_get_localestring (ditem, "X-GNOME-DocPath");
-
-	if (panel_is_url (docpath))
-                gnome_help_display_uri (docpath, &err);
-	else if (! panel_show_gnome_help (docpath, &err)) {
-		g_clear_error (&err);
-		panel_show_kde_help (docpath, &err);
-	}
-	
-        if (err != NULL) {
-		_gtk_error_dialog_run (NULL,
-				       ERROR_FORMAT,
-				       _("Could not display help"),
-				       err->message);
-                g_error_free (err);
-        }
-}
-
-
 static int
 get_child_position (QuickBox  *quick_box,
 		    GtkWidget *widget)
@@ -791,18 +640,6 @@ quick_lounge_util__get_unique_uri (QuickLounge *quick_lounge)
 }
 
 
-void
-quick_lounge_set_textdomain ()
-{
-	static gboolean domain_setted = FALSE;
-
-	if (!domain_setted) {
-		/* textdomain (GETTEXT_PACKAGE); FIXME */
-		domain_setted = TRUE;
-	}
-}
-
-
 /* -- */
 
 
@@ -971,13 +808,7 @@ populate_context_menu (GtkWidget *popup_menu,
 		       GtkWidget *button,
 		       gpointer   data)
 {
-	GtkWidget        *item;
-	GnomeDesktopItem *ditem;
-	const char       *docpath;
-
-	quick_lounge_set_textdomain ();
-
-	/**/
+	GtkWidget *item;
 
 	if (! QUICK_IS_SEPARATOR (button)) {
 		item = gtk_image_menu_item_new_with_mnemonic (_("_Properties"));
@@ -989,46 +820,16 @@ populate_context_menu (GtkWidget *popup_menu,
 				  "activate",
 				  G_CALLBACK (activate_item_cb), 
 				  button);
-	}
 
-	/**/
-
-	item = gtk_image_menu_item_new_with_mnemonic (_("_Help"));
-	gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), gtk_image_new_from_stock (GTK_STOCK_HELP, GTK_ICON_SIZE_MENU));
-	gtk_widget_show_all (item);
-
-	/**/
-
-	ditem = g_object_get_data (G_OBJECT (button), "ditem");
-	docpath = gnome_desktop_item_get_localestring (ditem, "X-GNOME-DocPath");
-	if (docpath != NULL) {
-		const char *app_name;
-		char       *label;
-
-		app_name = gnome_desktop_item_get_localestring (ditem, "Name");
-		label = g_strdup_printf (_("Help on %s Application"), app_name);
-		item = gtk_image_menu_item_new_with_mnemonic (label);
-		g_free (label);
-
-		gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
-		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), gtk_image_new_from_stock (GTK_STOCK_HELP, GTK_ICON_SIZE_MENU));
-		gtk_widget_show_all (item);
+		/**/
 		
-		g_signal_connect_swapped (G_OBJECT (item), 
-					  "activate",
-					  G_CALLBACK (item_help_on_app_cb), 
-					  button);
+		item = gtk_separator_menu_item_new ();
+		gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
+		gtk_widget_show_all (item);
 	}
 
 	/**/
 
-	item = gtk_separator_menu_item_new ();
-	gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
-	gtk_widget_show_all (item);
-
-	/**/
-
 	item = gtk_image_menu_item_new_with_mnemonic (_("Add _Launcher"));
 	gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
 	gtk_widget_show_all (item);
@@ -1137,6 +938,8 @@ drag_data_received  (GtkWidget          *widget,
                 return;
         }
 
+	gtk_drag_finish (context, TRUE, FALSE, time);
+
 	pos = quick_box_get_pointer_position (quick_box, x, y);
 
 	list = get_file_list_from_url_list ((char *) data->data);
@@ -1181,7 +984,6 @@ drag_data_received  (GtkWidget          *widget,
 	}
 	path_list_free (list);
 
-	gtk_drag_finish (context, TRUE, FALSE, time);
 	quick_lounge_save_order (quick_lounge);
 	dlg_properties_update (quick_lounge->prop_dialog);
 }
@@ -1414,7 +1216,7 @@ quick_lounge_load_uri_sync (QuickLounge  *quick_lounge,
 
 	for (scan = file_list; order_list && scan;) {
 		char *path = scan->data;
-		
+
 		if (path_in_list (order_list, path)) {
 			file_list = g_list_remove_link (file_list, scan);
 			g_list_free (scan);
@@ -1432,10 +1234,9 @@ quick_lounge_load_uri_sync (QuickLounge  *quick_lounge,
 	for (scan = files; scan; scan = scan->next) {
 		char *uri = scan->data;
 
-		if (*uri == 0)  
+		if (*uri == 0) 
 			quick_box_add_separator (quick_box, -1);
-
-		else if (is_desktop_file (uri))
+		else if (is_desktop_file (uri)) 
 			quick_box_add_button (quick_box, uri, -1);
 	}
 
@@ -1547,9 +1348,9 @@ copy_default_items_to_uri (const char *to_uri)
 {
 	static char * default_items [] = { 
 		/* FIXME : put default items here. */
-		"yelp.desktop",
-		"gnome-terminal.desktop",
 		"nautilus.desktop",
+		"gnome-terminal.desktop",
+		"yelp.desktop",
 		NULL
 	};
 	int i;
@@ -1620,7 +1421,11 @@ quick_lounge_applet_fill (PanelApplet *applet)
 
 	/**/
 
-	panel_applet_add_preferences (applet, "/schemas/apps/quick_lounge_applet/prefs", NULL);
+	panel_applet_add_preferences (applet, "/schemas/apps/quick-lounge-applet/prefs", &error);
+	if (error != NULL) {
+		g_print (error->message);
+		g_clear_error (&error);
+	}
 
 	min_cols = panel_applet_gconf_get_int (applet, PREFS_MIN_VISIBLE_COLS, &error);
 	if ((error != NULL) || (min_cols < 0)) {
@@ -1761,8 +1566,9 @@ quick_lounge_factory (PanelApplet *applet,
 }
 
 
-PANEL_APPLET_BONOBO_SHLIB_FACTORY (APPLET_FACTORY_IID,
-				   PANEL_TYPE_APPLET,
-				   "Quick Lounge Applet",
-				   quick_lounge_factory, 
-				   NULL);
+PANEL_APPLET_BONOBO_FACTORY (APPLET_FACTORY_IID,
+			     PANEL_TYPE_APPLET,
+			     "quick-lounge-applet",
+			     "0",
+			     quick_lounge_factory, 
+			     NULL)
